package com.ruoyi.project.business.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.ruoyi.project.business.domain.TpParabarDetail;
import java.util.List;

/**
 * 【请填写功能名称】Mapper接口
 *
 * @author ruoyi
 * @date 2024-04-28
 */
public interface TpParabarDetailMapper extends BaseMapper<TpParabarDetail> {

    /**
     * 查询【请填写功能名称】
     *
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    public TpParabarDetail selectTpParabarDetailById(Long id);

    /**
     * 查询【请填写功能名称】列表
     *
     * @param tpParabarDetail 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public List<TpParabarDetail> selectTpParabarDetailList(TpParabarDetail tpParabarDetail);

    /**
     * 新增【请填写功能名称】
     *
     * @param tpParabarDetail 【请填写功能名称】
     * @return 结果
     */
    public int insertTpParabarDetail(TpParabarDetail tpParabarDetail);

    /**
     * 修改【请填写功能名称】
     *
     * @param tpParabarDetail 【请填写功能名称】
     * @return 结果
     */
    public int updateTpParabarDetail(TpParabarDetail tpParabarDetail);

    /**
     * 删除【请填写功能名称】
     *
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
    public int deleteTpParabarDetailById(Long id);

    public int deleteTpParabarDetailByParabarId(Long parabarId);

    public int softDeleteTpParabarDetailByParabarId(Long[] parabarId);

    /**
     * 批量删除【请填写功能名称】
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTpParabarDetailByIds(Long[] ids);
}
